================================================
Platypus - Multiobjective Optimization in Python
================================================

Platypus is a framework for evolutionary computing in Python with a focus on
multiobjective evolutionary algorithms (MOEAs). It differs from existing
optimization libraries, including PyGMO, Inspyred, DEAP, and Scipy, by
providing optimization algorithms and analysis tools for multiobjective
optimization.

.. toctree::
   :maxdepth: 2
   
   getting-started
   experimenter


